@@ -5,6 +5,11 @@ from vocode.models.synthesizer import SynthesizerConfig
 from vocode.models.transcriber import TranscriberConfig
 
 
+class TwilioConfig(BaseModel):
+    account_sid: str
+    auth_token: str
+
+
 class CallEntity(BaseModel):
     phone_number: str
 
@@ -14,10 +19,12 @@ class CreateInboundCall(BaseModel):
     agent_config: AgentConfig
     synthesizer_config: Optional[SynthesizerConfig] = None
     twilio_sid: str
+    twilio_config: Optional[TwilioConfig] = None
 
 
 class EndOutboundCall(BaseModel):
     call_id: str
+    twilio_config: Optional[TwilioConfig] = None
 
 
 class CreateOutboundCall(BaseModel):
@@ -27,6 +34,7 @@ class CreateOutboundCall(BaseModel):
     agent_config: AgentConfig
     synthesizer_config: Optional[SynthesizerConfig] = None
     conversation_id: Optional[str] = None
+    twilio_config: Optional[TwilioConfig] = None
     # TODO add IVR/etc.
 
 
@@ -39,3 +47,4 @@ class DialIntoZoomCall(BaseModel):
     agent_config: AgentConfig
     synthesizer_config: Optional[SynthesizerConfig] = None
     conversation_id: Optional[str] = None
+    twilio_config: Optional[TwilioConfig] = None
