@@ -3,12 +3,13 @@ from typing import Optional
 import requests
 import uvicorn
 from vocode.models.synthesizer import SynthesizerConfig
+from twilio.jwt.access_token.grants import VoiceGrant
 
 from vocode.models.transcriber import TranscriberConfig
 from .. import api_key, BASE_URL
 
 from ..models.agent import AgentConfig
-from ..models.telephony import CreateInboundCall
+from ..models.telephony import CreateInboundCall, TwilioConfig, TwilioConfig
 
 VOCODE_INBOUND_CALL_URL = f"https://{BASE_URL}/create_inbound_call"
 
@@ -20,6 +21,7 @@ class InboundCallServer:
         transcriber_config: Optional[TranscriberConfig] = None,
         synthesizer_config: Optional[SynthesizerConfig] = None,
         response_on_rate_limit: Optional[str] = None,
+        twilio_config: Optional[TwilioConfig] = None,
     ):
         self.agent_config = agent_config
         self.transcriber_config = transcriber_config
@@ -30,6 +32,7 @@ class InboundCallServer:
             response_on_rate_limit
             or "The line is really busy right now, check back later!"
         )
+        self.twilio_config = twilio_config
 
     async def handle_call(self, twilio_sid: str = Form(alias="CallSid")):
         response = requests.post(
@@ -40,6 +43,7 @@ class InboundCallServer:
                 twilio_sid=twilio_sid,
                 transcriber_config=self.transcriber_config,
                 synthesizer_config=self.synthesizer_config,
+                twilio_config=self.twilio_config,
             ).dict(),
         )
         if response.status_code == 429:
